@@ -159,15 +159,15 @@ class LambdaToDynamoDB(
 
         jsii.create(LambdaToDynamoDB, self, [scope, id, props])
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="dynamoTable")
     def dynamo_table(self) -> aws_cdk.aws_dynamodb.Table:
-        return jsii.get(self, "dynamoTable")
+        return typing.cast(aws_cdk.aws_dynamodb.Table, jsii.get(self, "dynamoTable"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
-        return jsii.get(self, "lambdaFunction")
+        return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
 
 @jsii.data_type(
@@ -223,7 +223,7 @@ class LambdaToDynamoDBProps:
         :default: - Default props are used
         """
         result = self._values.get("dynamo_table_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.TableProps], result)
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -232,7 +232,7 @@ class LambdaToDynamoDBProps:
         :default: - None
         """
         result = self._values.get("existing_lambda_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
 
     @builtins.property
     def existing_table_obj(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
@@ -241,7 +241,7 @@ class LambdaToDynamoDBProps:
         :default: - None
         """
         result = self._values.get("existing_table_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.Table], result)
 
     @builtins.property
     def lambda_function_props(
@@ -252,7 +252,7 @@ class LambdaToDynamoDBProps:
         :default: - Default props are used
         """
         result = self._values.get("lambda_function_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
 
     @builtins.property
     def table_permissions(self) -> typing.Optional[builtins.str]:
@@ -263,7 +263,7 @@ class LambdaToDynamoDBProps:
         :default: - Read/write access is given to the Lambda function if no value is specified.
         """
         result = self._values.get("table_permissions")
-        return result
+        return typing.cast(typing.Optional[builtins.str], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
